@@ -164,9 +164,16 @@ def _create_admin_user(keystone, admin_email, admin_password):
     admin_tenant = keystone.tenants.find(name='admin')
     admin_role = keystone.roles.find(name='admin')
 
-    LOG.debug('Creating admin user.')
-    admin_user = keystone.users.create('admin', email=admin_email,
-                                       password=admin_password,
-                                       tenant_id=admin_tenant.id)
-    LOG.debug('Granting admin role to admin user on admin tenant.')
-    keystone.roles.add_user_role(admin_user, admin_role, admin_tenant)
+    try:
+        admin_user = keystone.users.find(name='admin')
+        LOG.debug('Admin user already exists, skip creation')
+    except exceptions.NotFound:
+        LOG.debug('Creating admin user.')
+        admin_user = keystone.users.create('admin', email=admin_email,
+                                           password=admin_password,
+                                           tenant_id=admin_tenant.id)
+    if admin_role in keystone.roles.roles_for_user(admin_user, admin_tenant):
+        LOG.debug('Admin user is already granted admin role with admin tenant')
+    else:
+        LOG.debug('Granting admin role to admin user on admin tenant.')
+        keystone.roles.add_user_role(admin_user, admin_role, admin_tenant)
